@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-adblock-manager.c 6742 2006-12-17 18:09:55Z jframeau $
+ *  $Id: ephy-adblock-manager.c 6931 2007-03-02 23:35:44Z bberg $
  */
 
 #include "config.h"
@@ -66,12 +66,14 @@ ephy_adblock_manager_set_blocker (EphyAdBlockManager *self,
  **/
 gboolean
 ephy_adblock_manager_should_load (EphyAdBlockManager *self,
+				  EphyEmbed *embed,
 	    	 	    	  const char *url,
 	    	 	    	  AdUriCheckType check_type)
 {
 	if (self->priv->blocker != NULL)
 	{
 		return ephy_adblock_should_load (self->priv->blocker,	
+						 embed,
 						 url,
 						 check_type);
 	}
