@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: EphyContentPolicy.cpp 6589 2006-09-13 11:49:01Z chpe $
+ *  $Id: EphyContentPolicy.cpp 6931 2007-03-02 23:35:44Z bberg $
  */
 
 #include "mozilla-config.h"
@@ -25,12 +25,15 @@
 #include <nsStringAPI.h>
 
 #include <nsCOMPtr.h>
+#include <nsICategoryManager.h>
 #include <nsIDOMAbstractView.h>
 #include <nsIDOMDocument.h>
 #include <nsIDOMDocumentView.h>
 #include <nsIDOMNode.h>
 #include <nsIDOMWindow.h>
 #include <nsIURI.h>
+#include <nsServiceManagerUtils.h>
+#include <nsXPCOMCID.h>
 
 #include "eel-gconf-extensions.h"
 #include "ephy-adblock-manager.h"
@@ -148,22 +151,23 @@ EphyContentPolicy::ShouldLoad(PRUint32 aContentType,
 		PR_TRUE  /* TYPE_REFRESH */
 	};
 
-	if (kBlockType[aContentType < G_N_ELEMENTS (kBlockType) ? aContentType : 0] &&
-	    !ephy_adblock_manager_should_load (adblock_manager, 
-					       contentSpec.get (), 
-					       AdUriCheckType (aContentType)))
+	if (kBlockType[aContentType < G_N_ELEMENTS (kBlockType) ? aContentType : 0])
 	{
-		*aDecision = nsIContentPolicy::REJECT_REQUEST;
+		GtkWidget *embed = GetEmbedFromContext (aContext);
 
-		GtkWidget *embed = GetEmbedFromContext (aContext); 
-
-		if (embed) 
+		if (embed &&
+		    !ephy_adblock_manager_should_load (adblock_manager,
+						       EPHY_EMBED (embed),
+						       contentSpec.get (),
+						       AdUriCheckType (aContentType)))
 		{
+			*aDecision = nsIContentPolicy::REJECT_REQUEST;
+
 			g_signal_emit_by_name (embed,
 					       "content-blocked", 
 					       contentSpec.get ());
+			return NS_OK;
 		}
-		return NS_OK;
 	}
 
 	PRBool isHttp = PR_FALSE;
@@ -197,3 +201,44 @@ EphyContentPolicy::ShouldProcess(PRUint32 aContentType,
 	*aDecision = nsIContentPolicy::ACCEPT;
 	return NS_OK;
 }
+
+
+/* static */ NS_METHOD
+EphyContentPolicy::Register (nsIComponentManager* aComponentManager,
+			     nsIFile* aPath,
+			     const char* aRegistryLocation,
+			     const char* aComponentType,
+			     const nsModuleComponentInfo* aInfo)
+{
+  nsresult rv;
+  nsCOMPtr<nsICategoryManager> catMan (do_GetService(NS_CATEGORYMANAGER_CONTRACTID, &rv));
+  NS_ENSURE_SUCCESS (rv, rv);
+
+  rv = catMan->AddCategoryEntry ("content-policy",
+				 EPHY_CONTENT_POLICY_CONTRACTID,
+				 EPHY_CONTENT_POLICY_CONTRACTID,
+				 PR_FALSE /* don't persist */,
+				 PR_TRUE /* replace */,
+				 nsnull);
+  NS_ENSURE_SUCCESS (rv, rv);
+
+  return rv;
+}
+
+/* static */ NS_METHOD
+EphyContentPolicy::Unregister (nsIComponentManager* aComponentManager,
+			       nsIFile* aPath,
+			       const char* aRegistryLocation,
+			       const nsModuleComponentInfo* aInfo)
+{
+  nsresult rv;
+  nsCOMPtr<nsICategoryManager> catMan (do_GetService(NS_CATEGORYMANAGER_CONTRACTID, &rv));
+  NS_ENSURE_SUCCESS (rv, rv);
+
+  rv = catMan->DeleteCategoryEntry ("content-policy",
+				    EPHY_CONTENT_POLICY_CONTRACTID,
+				    PR_FALSE /* don't persist */);
+  NS_ENSURE_SUCCESS (rv, rv);
+
+  return rv;
+}
