@@ -1,7 +1,7 @@
 /*
- *  Copyright (C) 2000-2004 Marco Pesenti Gritti
- *  Copyright (C) 2003, 2004 Christian Persch
- *  Copyright (C) 2004 Crispin Flowerday
+ *  Copyright © 2000-2004 Marco Pesenti Gritti
+ *  Copyright © 2003, 2004 Christian Persch
+ *  Copyright © 2004 Crispin Flowerday
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: EventContext.cpp,v 1.66 2006/08/07 20:04:54 chpe Exp $
+ *  $Id: EventContext.cpp 6618 2006-09-29 19:32:40Z chpe $
  */
 
 #include "mozilla-config.h"
@@ -935,6 +935,9 @@ nsresult EventContext::CheckLinkScheme (const nsAString &link)
 	    g_ascii_strcasecmp (scheme.get(), "https") == 0 ||
 	    g_ascii_strcasecmp (scheme.get(), "ftp") == 0 ||
 	    g_ascii_strcasecmp (scheme.get(), "file") == 0 ||
+	    g_ascii_strcasecmp (scheme.get(), "smb") == 0 ||
+	    g_ascii_strcasecmp (scheme.get(), "sftp") == 0 ||
+	    g_ascii_strcasecmp (scheme.get(), "ssh") == 0 ||
 	    g_ascii_strcasecmp (scheme.get(), "data") == 0 ||
 	    g_ascii_strcasecmp (scheme.get(), "resource") == 0 ||
 	    g_ascii_strcasecmp (scheme.get(), "about") == 0 ||
