@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-stock-icons.c 6761 2006-12-19 17:03:22Z lferrett $
+ *  $Id: ephy-stock-icons.c 6830 2007-01-18 12:36:08Z lferrett $
  */
 
 #include "config.h"
@@ -43,7 +43,6 @@ ephy_stock_icons_init (void)
 		STOCK_NEW_WINDOW,
 		STOCK_SEND_MAIL,
 		STOCK_ADD_BOOKMARK,
-		STOCK_BOOKMARK,
 		STOCK_PRINT_SETUP,
 		STOCK_LOCK_INSECURE,
 		STOCK_LOCK_SECURE,
@@ -54,6 +53,7 @@ ephy_stock_icons_init (void)
 	{
 		{ EPHY_STOCK_POPUPS,	N_("Popup Windows"),	0, 0, NULL },
 		{ EPHY_STOCK_HISTORY,	N_("History"),		0, 0, NULL },
+		{ EPHY_STOCK_BOOKMARK,  N_("Bookmark"),         0, 0, NULL },
 		{ EPHY_STOCK_BOOKMARKS, N_("Bookmarks"),	0, 0, NULL },
 		{ EPHY_STOCK_ENTRY,	N_("Address Entry"),	0, 0, NULL },
 		{ EPHY_STOCK_DOWNLOAD,	N_("_Download"),	0, 0, NULL }
