@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: ephy-bookmarks-editor.c,v 1.199 2006/12/17 19:20:50 chpe Exp $
+ * $Id: ephy-bookmarks-editor.c 6810 2007-01-09 00:40:44Z diegoe $
  */
 
 #include "config.h"
@@ -194,7 +194,7 @@ static const GtkActionEntry ephy_bookmark_popup_entries [] = {
 	{ "OpenInTab", STOCK_NEW_TAB, N_("Open in New _Tab"), "<shift><control>O",
 	  N_("Open the selected bookmark in a new tab"), 
 	  G_CALLBACK (cmd_open_bookmarks_in_tabs) },
-	{ "Rename", NULL, N_("_Rename..."), "F2",
+	{ "Rename", NULL, N_("_Rename…"), "F2",
 	  N_("Rename the selected bookmark or topic"), G_CALLBACK (cmd_rename) },
 	{ "Delete", GTK_STOCK_DELETE, N_("_Delete"), NULL,
 	  N_("Delete the selected bookmark or topic"), 
@@ -202,10 +202,10 @@ static const GtkActionEntry ephy_bookmark_popup_entries [] = {
 	{ "Properties", GTK_STOCK_PROPERTIES, N_("_Properties"), "<alt>Return",
 	  N_("View or modify the properties of the selected bookmark"), 
 	  G_CALLBACK (cmd_bookmark_properties) },
-	{ "Import", NULL, N_("_Import Bookmarks..."), NULL,
+	{ "Import", NULL, N_("_Import Bookmarks…"), NULL,
 	  N_("Import bookmarks from another browser or a bookmarks file"), 
 	  G_CALLBACK (cmd_bookmarks_import) },
-	{ "Export", NULL, N_("_Export Bookmarks..."), NULL,
+	{ "Export", NULL, N_("_Export Bookmarks…"), NULL,
 	  N_("Export bookmarks to a file"), 
 	  G_CALLBACK (cmd_bookmarks_export) },	  
 	{ "Close", GTK_STOCK_CLOSE, N_("_Close"), "<control>W",
@@ -1366,7 +1366,7 @@ ephy_bookmarks_editor_update_menu (EphyBookmarksEditor *editor)
 		EphyNode *node = selected->data;
 		char name[EPHY_BOOKMARK_ACTION_NAME_BUFFER_SIZE];
 
-		g_return_if_fail (node != NULL);
+		if (node == NULL) return;
 
 		mutable = !ephy_node_get_property_boolean (node, EPHY_NODE_BMK_PROP_IMMUTABLE);
 		
