@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-history-window.c 6778 2007-01-02 19:47:49Z diegoe $
+ *  $Id: ephy-history-window.c 6810 2007-01-09 00:40:44Z diegoe $
  */
 
 #include "config.h"
@@ -178,7 +178,7 @@ static const GtkActionEntry ephy_history_ui_entries [] = {
 	{ "Delete", GTK_STOCK_DELETE, N_("_Delete"), NULL,
 	  N_("Delete the selected history link"),
 	  G_CALLBACK (cmd_delete) },
-	{ "BookmarkLink", STOCK_ADD_BOOKMARK, N_("Add _Bookmark..."), "<control>D",
+	{ "BookmarkLink", STOCK_ADD_BOOKMARK, N_("Add _Bookmark…"), "<control>D",
 	  N_("Bookmark the selected history link"),
 	  G_CALLBACK (cmd_bookmark_link) },
 	{ "Close", GTK_STOCK_CLOSE, N_("_Close"), "<control>W",
