@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-location-action.c,v 1.45.2.2 2006/09/13 11:48:52 chpe Exp $
+ *  $Id: ephy-location-action.c 6756 2006-12-18 12:35:02Z chpe $
  */
 
 #include "config.h"
@@ -139,7 +139,7 @@ action_activated_cb (GtkEntryCompletion *completion,
 		if (url == NULL) return;
 
  		ephy_link_open (EPHY_LINK (action), url, NULL,
-			        ephy_link_flags_from_current_event ());
+			        ephy_link_flags_from_current_event () | EPHY_LINK_ALLOW_FIXUP);
 
 		g_free (url);
 	}
@@ -162,7 +162,7 @@ entry_activate_cb (GtkEntry *entry,
 	g_return_if_fail (address != NULL);
 
 	ephy_link_open (EPHY_LINK (action), address, NULL, 
-		        ephy_link_flags_from_current_event ());
+		        ephy_link_flags_from_current_event () | EPHY_LINK_ALLOW_FIXUP);
 
 	g_free (address);
 }
@@ -368,7 +368,9 @@ connect_proxy (GtkAction *action, GtkWidget *proxy)
 						    EPHY_COMPLETION_TEXT_COL,
 						    EPHY_COMPLETION_ACTION_COL,
 						    EPHY_COMPLETION_KEYWORDS_COL,
-						    EPHY_COMPLETION_RELEVANCE_COL);
+						    EPHY_COMPLETION_RELEVANCE_COL,
+						    EPHY_COMPLETION_EXTRA_COL,
+						    EPHY_COMPLETION_FAVICON_COL);
 
 		add_completion_actions (action, proxy);
 
