@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-net-monitor.c 6588 2006-09-13 11:34:25Z chpe $
+ *  $Id: ephy-net-monitor.c 6935 2007-03-04 14:45:24Z chpe $
  */
 
 #include "config.h"
@@ -111,6 +111,8 @@ ephy_net_monitor_check_network (EphyNetMonitor *monitor)
 	DBusMessage *message;
 	DBusPendingCall* reply;
 
+	if (priv->bus == NULL) return;
+
 	LOG ("EphyNetMonitor checking network");
 
 	/* ask to Network Manager if there is at least one active device */
@@ -248,13 +250,16 @@ ephy_net_monitor_startup (EphyNetMonitor *monitor)
 
 	ephy_net_monitor_attach_to_dbus (monitor);
 
-	/* DBUS may disconnect us at any time. So listen carefully to it */
-	g_signal_connect (dbus, "connected",  
-			  G_CALLBACK (connect_to_system_bus_cb), monitor);
-	g_signal_connect (dbus, "disconnected",  
-			  G_CALLBACK (disconnect_from_system_bus_cb), monitor);
+	if (monitor->priv->bus != NULL)
+       	{
+		/* DBUS may disconnect us at any time. So listen carefully to it */
+		g_signal_connect (dbus, "connected",  
+				  G_CALLBACK (connect_to_system_bus_cb), monitor);
+		g_signal_connect (dbus, "disconnected",  
+				  G_CALLBACK (disconnect_from_system_bus_cb), monitor);
 
-	ephy_net_monitor_check_network (monitor);
+		ephy_net_monitor_check_network (monitor);
+	}
 }
 
 static void
