@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-statusbar.h 6589 2006-09-13 11:49:01Z chpe $
+ *  $Id: ephy-statusbar.h 6711 2006-12-03 19:05:19Z chpe $
  */
 
 #ifndef EPHY_STATUSBAR_H
@@ -45,8 +45,6 @@ struct _EphyStatusbar
 
 	/*< public >*/
 	GtkTooltips *tooltips;
-	GtkWidget *security_frame;
-	GtkWidget *popups_manager_frame;
 
 	/*< private >*/
         EphyStatusbarPrivate *priv;
