@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: pdm-dialog.c 6589 2006-09-13 11:49:01Z chpe $
+ *  $Id: pdm-dialog.c 6772 2006-12-30 22:15:15Z chpe $
  */
 
 #include "config.h"
@@ -30,6 +30,7 @@
 #include "ephy-gui.h"
 #include "ephy-state.h"
 #include "ephy-string.h"
+#include "ephy-stock-icons.h"
 #include "ephy-debug.h"
 
 #include <gtk/gtklabel.h>
@@ -1205,7 +1206,7 @@ pdm_dialog_init (PdmDialog *dialog)
 
 	ephy_gui_ensure_window_group (GTK_WINDOW (window));
 
-	gtk_window_set_icon_name (GTK_WINDOW (window), "web-browser");
+	gtk_window_set_icon_name (GTK_WINDOW (window), EPHY_STOCK_EPHY);
 
 	g_signal_connect (window, "response",
 			  G_CALLBACK (pdm_dialog_response_cb), dialog);
